@@ -686,7 +686,7 @@ class NumerousClient:
         self._base_client.ClearData(
             spm_pb2.Scenario(scenario=scenario))
 
-    def data_write_df(self, df:pd.DataFrame, scenario=None, clear=True):
+    def data_write_df(self, df, scenario=None, clear=True):
         if scenario is None:
             scenario = self._scenario
 
